@@ -19,7 +19,7 @@
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "powerpc64le-unknown-linux-gnu"
+#define LLVM_DEFAULT_TARGET_TRIPLE "riscv64-unknown-linux-gnu"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,28 +28,28 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "powerpc64le-unknown-linux-gnu"
+#define LLVM_HOST_TRIPLE "riscv64-unknown-linux-gnu"
 
 /* LLVM architecture name for the native architecture, if available */
-#define LLVM_NATIVE_ARCH PowerPC
+#define LLVM_NATIVE_ARCH RISCV
 
 /* LLVM name for the native AsmParser init function, if available */
-#define LLVM_NATIVE_ASMPARSER LLVMInitializePowerPCAsmParser
+#define LLVM_NATIVE_ASMPARSER LLVMInitializeRISCVAsmParser
 
 /* LLVM name for the native AsmPrinter init function, if available */
-#define LLVM_NATIVE_ASMPRINTER LLVMInitializePowerPCAsmPrinter
+#define LLVM_NATIVE_ASMPRINTER LLVMInitializeRISCVAsmPrinter
 
 /* LLVM name for the native Disassembler init function, if available */
-#define LLVM_NATIVE_DISASSEMBLER LLVMInitializePowerPCDisassembler
+#define LLVM_NATIVE_DISASSEMBLER LLVMInitializeRISCVDisassembler
 
 /* LLVM name for the native Target init function, if available */
-#define LLVM_NATIVE_TARGET LLVMInitializePowerPCTarget
+#define LLVM_NATIVE_TARGET LLVMInitializeRISCVTarget
 
 /* LLVM name for the native TargetInfo init function, if available */
-#define LLVM_NATIVE_TARGETINFO LLVMInitializePowerPCTargetInfo
+#define LLVM_NATIVE_TARGETINFO LLVMInitializeRISCVTargetInfo
 
 /* LLVM name for the native target MC init function, if available */
-#define LLVM_NATIVE_TARGETMC LLVMInitializePowerPCTargetMC
+#define LLVM_NATIVE_TARGETMC LLVMInitializeRISCVTargetMC
 
 /* LLVM name for the native target MCA init function, if available */
 /* #undef LLVM_NATIVE_TARGETMCA */
